@@ -5,18 +5,17 @@
 #include <QWidget>
 #include <QMetaMethod>
 
-//namespace engine {
-//class Engine ;
-//}
-
+namespace handle {
+class Handle ;
+}
 namespace adaptor {
 class Adaptor ;
 }
 
-
 namespace host {
 
 enum InputDevice { UnknownInputDevice = 0, HardwareInputDevice = 1, OnscreenInputDevice = 2 } ;
+enum InputLanguage { UnknownLanguage = 0, SimplifiedChinese = 1 } ;
 
 class Host : public QObject {
 
@@ -26,27 +25,25 @@ class Host : public QObject {
 
 signals :
     void inputDeviceChanged() ;
+    void inputLanguageChanged() ;
     void cursorRectUpdate( int x, int y, int width, int height ) ;
-    void receiveSurrounding( const QString& surrounding ) ;
-    void setKeyboardLayout( int layout ) ;
-    void queryStatus() ;
-    void sendStatus( int status ) ;
 
 public :
     QWidget* view ;
-    QWidget* extraInputPanel ;
-    QObject* engine ;
+    QObject* handle ;
     QRect cursorRect ;
     InputDevice inputDevice ;
+    InputLanguage inputLanguage ;
     adaptor::Adaptor* adaptor ;
 
     QMetaMethod processKeyPress ;
     QMetaMethod processKeyRelease ;
+    QMetaMethod requestReset ;
+    QMetaMethod setKeyboardLayout ;
 
     Host( QObject* parent = NULL ) ;
     void setView( QWidget* view ) ;
-    void setExtraInputPanel( QWidget* extraInputPanel ) ;
-    void setEngine( QObject* engine ) ;
+    void setHandle( QObject* handle ) ;
 
     Q_INVOKABLE void show() ;
     Q_INVOKABLE void hide() ;
@@ -55,6 +52,8 @@ public :
     Q_INVOKABLE void sendCommit( const QString& text ) ;
     Q_INVOKABLE void sendKeyPress( int keycode, int modifiers ) ;
     Q_INVOKABLE void sendKeyRelease( int keycode, int modifiers ) ;
+    Q_INVOKABLE void setInputDevice( InputDevice inputDevice ) ;
+    Q_INVOKABLE void setInputLanguage( InputLanguage inputLanguage ) ;
 } ;
 
 }
