@@ -36,11 +36,14 @@ int main( int argc, char** argv ) {
     host->setHandle( handle ) ;
 
     view::View* view = new view::View() ;
+    view->setInputContext( NULL ) ;
     host->setView( view ) ;
 
+#ifdef Q_WS_MAEMO_5
     extra::ExtraInputPanel* extraInputPanel = new extra::ExtraInputPanel() ;
     extraInputPanel->setInputContext( NULL ) ;
     host->adaptor->setExtraInputPanel( extraInputPanel ) ;
+#endif
 
     QDesktopWidget* desktop = QApplication::desktop() ;
     view->setGeometry( desktop->geometry() ) ;
@@ -97,6 +100,7 @@ int main( int argc, char** argv ) {
     QDBusConnection::systemBus().connect( "org.freedesktop.Hal", "/org/freedesktop/Hal/devices/platform_slide", "org.freedesktop.Hal.Device", "PropertyModified", host->adaptor, SLOT(checkKeyboardStatus()) ) ;
     engine->setKeyboardLayout( engine::Engine::FullKeyboardLayout ) ;
     host->adaptor->checkKeyboardStatus() ;
+    QDBusConnection::sessionBus().connect( "", "", "inputmethod.context", "setFocusedWindowId", host->adaptor, SLOT(setFocusedWindowId(quint64)) ) ;
 #endif 
     return app.exec() ;
 }
